pub enum ZeroPadding {}Expand description
Implementation of basic Zero Padding. May not be reversible if the original data ends with one or more zero bytes. Does not add an extra block of padding if the data length is already a multiple of the block size